# Author: Kristyna Janku, structure inspired by "custom_dataset.py"

import glob
import os
import numpy as np
import json


class CTCDataset(object):
    def __init__(self, root_dir, name, subset):
        super().__init__()
        self.root_dir = root_dir
        self.name = name
        self.subset = subset
        annotation_file_path = os.path.join(self.root_dir, "annotation", "SOT", self.name + ".json")
        with open(annotation_file_path) as ann:
            self.annotation_json = json.load(ann)
            self.seq_names = list(self.annotation_json.keys())
            assert len(self.seq_names) > 0
            print("CTC dataset seqs ", self.seq_names)

    def __getitem__(self, index):
        assert 0 <= index <= len(self.seq_names)
        seq = self.seq_names[index]
        imgs = [os.path.join(self.root_dir, "raw_data", self.subset, img) for img in self.annotation_json[seq]['img_names']]
        bbox = np.array([float(x) for x in self.annotation_json[seq]['init_rect']])
        return imgs, bbox[np.newaxis]

    def __len__(self):
        return len(self.seq_names)
